// Code generated by hertz generator.

package main

import (
	"context"
	"fmt"
	"github.com/cloudwego/hertz/pkg/app/server"
	"github.com/hertz-contrib/cors"
	"github.com/robfig/cron/v3"
	"pji_desktop_http/biz/dal"
	"pji_desktop_http/biz/handler/map_service"
	"pji_desktop_http/common/config"
	"pji_desktop_http/common/config/c_log"
	"pji_desktop_http/pji_client"
	"time"
)

func main() {
	// 初始化数据库
	dal.Init()
	// 初始化日志
	c_log.InitLog("logs/", "desktop_http")
	// 初始化oss
	config.InitOssConfig()
	// 初始化朴津sdk
	pji_client.InitApiClient()
	// 添加调度器
	c := cron.New()
	// 添加定时任务
	ctx := context.Background()
	_, err := c.AddFunc("@every 30m", func() {
		// 发送地图续扫通知
		flag := map_service.AddMapRescanNotifyWithoutHttp(ctx)
		if flag {
			fmt.Println("轮询地图续扫提醒结束")
		}
		flag = map_service.UploadOriginalMapWithoutHttp(ctx)
		if flag {
			fmt.Println("轮询上传原始地图结束")
		}
	})

	_, err = c.AddFunc("@every 10m", func() {
		flag := map_service.UpdateMapDeployStatusWithoutHttp(ctx)
		if flag {
			fmt.Println("轮询更新地图下发状态成功")
		}
	})

	if err != nil {
		return
	}
	// 启动调度器
	c.Start()
	h := server.New(
		server.WithStreamBody(true),
		server.WithIdleTimeout(time.Minute*10),
	)
	h.Use(cors.New(cors.Config{
		AllowOrigins:     []string{"*"},
		AllowMethods:     []string{"POST, GET, OPTIONS, PUT, DELETE, UPDATE"},
		AllowHeaders:     []string{"Origin, X-Requested-With, Content-Type, Accept, Authorization"},
		ExposeHeaders:    []string{"Content-Length, Content-Disposition, Access-Control-Allow-Origin, Access-Control-Allow-Headers, Cache-Control, Content-Language, Content-Type"},
		AllowCredentials: true,
	}))
	register(h)
	h.Spin()
}
